/*
 	File:		AVComponents.h
 
 	Contains:	Standard includes for standard AV panels
 
 	Version:	Technology:	System 7.5
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*/
#ifndef __AVCOMPONENTS__
#define __AVCOMPONENTS__

#ifndef __DIALOGS__
#include <Dialogs.h>
#endif
#ifndef __VIDEO__
#include <Video.h>
#endif
#ifndef __DISPLAYS__
#include <Displays.h>
#endif
#ifndef __COMPONENTS__
#include <Components.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

#ifndef FOR_SYSTEM7_AND_SYSTEM8_COOPERATIVE
#define FOR_SYSTEM7_AND_SYSTEM8_COOPERATIVE 1
#endif
#if FOR_SYSTEM7_AND_SYSTEM8_COOPERATIVE
/*
	The subtypes listed here are for example only.  The display manager will find _all_ panels
  	with the appropriate types.  These panels return class information that is used to devide them
  	up into groups to be displayed in the AV Windows (class means "geometry" or "color" or other groupings
  	like that.
*/

enum {
	kAVPanelType				= 'avpc',						/* Panel subtypes			*/
	kBrightnessPanelSubType		= 'brit',
	kContrastPanelSubType		= 'cont',
	kBitDepthPanelSubType		= 'bitd',
	kAVEngineType				= 'avec',						/* Engine subtypes				*/
	kBrightnessEngineSubType	= 'brit',
	kContrastEngineSubType		= 'cont',						/*		kBitDepthEngineSubType		= 'bitd',			// Not used					*/
	kAVPortType					= 'avdp'						/*subtypes are defined in each port's public .h file*/
};

/*
 PortComponent subtypes are up to the port and display manager does not use the subtype
	to find port components.  Instead, display manager uses an internal cache to search for portcompoennts.
	It turns out to be useful to have a unique subtype so that engines can see if they should apply themselves to
	a particular port component.
  
   PortKinds are the "class" of port.  When a port is registered with display manager (creating a display ID), the
	caller of DMNewDisplayIDByPortComponent passes a portKind.  Ports of this type are returned by
	DMNewDevicePortList.
  
   PortKinds are NOT subtypes of components
   PortKinds ARE used to register and find port components with Display Manager.  Here are the basic port kinds:
  
   Video displays are distinct from video out because there are some video out ports that are not actaully displays.
	if EZAV is looking to configure displays, it needs to look for kAVVideoDisplayPortKind not kAVVideoOutPortKind.
*/

enum {
	kAVVideoDisplayPortKind		= 'pkdo',						/* Video Display (CRT or panel display)				*/
	kAVVideoOutPortKind			= 'pkvo',						/* Video out port (camera output).					  */
	kAVVideoInPortKind			= 'pkvi',						/* Video in port (camera input)						*/
	kAVSoundOutPortKind			= 'pkso',						/* Sound out port (speaker or speaker jack)			*/
	kAVSoundInPortKind			= 'pksi',						/* Sound in port (microphone or microphone jack)	*/
	kAVDeviceType				= 'avdc',						/* Device Component subtypes are up to the manufacturor since each device may contain multiple function types (eg telecaster) */
	kAVDisplayDeviceKind		= 'dkvo',						/* Display device*/
																/* Device Component subtypes are up to the manufacturor since each device may contain multiple function types (eg telecaster)*/
	kAVCategoryType				= 'avcc',
	kAVSoundInSubType			= 'avao',
	kAVSoundOutSubType			= 'avai',
	kAVVideoInSubType			= 'vdin',
	kAVVideoOutSubType			= 'vdou',
	kAVInvalidType				= 'badt'						/* Some calls return a component type, in case of errors, these types are set to kAVInvalidComponentType */
};

/*
 Constants for Panel Classes (used to build buttons in AVSetup) 
 but is generic to all panels 
*/

enum {
	kAVPanelClassDisplayDefault	= 'cdsp',
	kAVPanelClassColor			= 'cclr',
	kAVPanelClassGeometry		= 'cgeo',
	kAVPanelClassSound			= 'csnd',
	kAVPanelClassPreferences	= 'cprf'
};

/* =============================					*/
/* Component interface revision levels and history	*/
/* =============================					*/

enum {
	kAVPanelComponentInterfaceRevOne = 1,
	kAVEngineComponentInterfaceRevOne = 1,
	kAVPortComponentInterfaceRevOne = 1,
	kAVDeviceComponentInterfaceRevOne = 1
};


enum {
	kBaseAVComponentSelector	= 256							/* First apple-defined selector for engine components */
};

/* =============================				*/
/* Panel Standard component selectors			*/
/* =============================				*/

enum {
	kAVPanelFakeRegisterSelect	= kComponentRegisterSelect,		/* -5	*/
	kAVPanelSetCustomDataSelect	= 0,
	kAVPanelGetDitlSelect		= 1,
	kAVPanelGetTitleSelect		= 2,
	kAVPanelInstallSelect		= 3,
	kAVPanelEventSelect			= 4,
	kAVPanelItemSelect			= 5,
	kAVPanelRemoveSelect		= 6,
	kAVPanelValidateInputSelect	= 7,
	kAVPanelGetSettingsIdentifiersSelect = 8,
	kAVPanelGetSettingsSelect	= 9,
	kAVPanelSetSettingsSelect	= 10,
	kAVPanelSelectorGetFidelity	= kBaseAVComponentSelector,
	kAVPanelSelectorTargetDevice = 257,
	kAVPanelSelectorGetPanelClass = 258
};

/* =============================				*/
/* Engine Standard component selectors			*/
/* =============================				*/

enum {
	kAVEngineSelectorGetEngineFidelity = kBaseAVComponentSelector,
	kAVEngineSelectorTargetDevice = 257
};

/* =============================					*/
/* Video Port Specific calls						*/
/* =============================					*/

enum {
	kAVPortCheckTimingMode		= 0
};

/* =============================					*/
/* AV Port Specific calls							*/
/* =============================					*/

enum {
	kAVPortGetAVDeviceFidelity	= kBaseAVComponentSelector,		/* Port Standard Component selectors */
	kAVPortGetWiggle			= 257,
	kAVPortSetWiggle			= 258,
	kAVPortGetName				= 259,
	kAVPortGetGraphicInfo		= 260,
	kAVPortSetActive			= 261,
	kAVPortGetActive			= 262,
	kAVPortUnsed1				= 263,							/* Selector removed as part of API change.  We don't want to mess up the following selectors, so we put in this spacer (ie kPadSelector). */
	kAVPortGetAVID				= 264,
	kAVPortSetAVID				= 265,
	kAVPortSetDeviceAVID		= 266,							/* For registrar to set device (instead of hitting global directly) -- should only be called once */
	kAVPortGetDeviceAVID		= 267,							/* Called by display mgr for generic ports */
	kAVPortGetPowerState		= 268,
	kAVPortSetPowerState		= 269
};

/* =============================					*/
/* Device Component Standard Component selectors	*/
/* =============================					*/

enum {
	kAVDeviceGetName			= kBaseAVComponentSelector,
	kAVDeviceGetGraphicInfo		= 257,
	kAVDeviceGetPowerState		= 258,
	kAVDeviceSetPowerState		= 259,
	kAVDeviceGetAVID			= 260,							/*		Not yet implemented*/
	kAVDeviceSetAVID			= 261							/* For registrar to set AVID (should be called only once)*/
};

/* =============================				*/
/* Engine Standard component selectors			*/
/* =============================				*/
extern pascal ComponentResult AVEngineComponentGetFidelity(ComponentInstance engineComponent, DisplayIDType displayID, DMFidelityType *engineFidelity)
 FIVEWORDINLINE(0x2F3C, 0x0008, 0x0100, 0x7000, 0xA82A);

extern pascal ComponentResult AVEngineComponentTargetDevice(ComponentInstance engineComponent, DisplayIDType displayID)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0101, 0x7000, 0xA82A);

/* =============================				*/
/* Panel Standard Component calls				*/
/* =============================				*/
extern pascal ComponentResult AVPanelFakeRegister(ComponentInstance ci)
 FIVEWORDINLINE(0x2F3C, 0x0000, 0xFFFB, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelSetCustomData(ComponentInstance ci, long theCustomData)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0000, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelGetDitl(ComponentInstance ci, Handle *ditl)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0001, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelGetTitle(ComponentInstance ci, StringPtr title)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0002, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelInstall(ComponentInstance ci, DialogPtr dialog, short itemOffset)
 FIVEWORDINLINE(0x2F3C, 0x0006, 0x0003, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelEvent(ComponentInstance ci, DialogPtr dialog, short itemOffset, EventRecord *event, short *itemHit, Boolean *handled)
 FIVEWORDINLINE(0x2F3C, 0x0012, 0x0004, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelItem(ComponentInstance ci, DialogPtr dialog, short itemOffset, short itemNum)
 FIVEWORDINLINE(0x2F3C, 0x0008, 0x0005, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelRemove(ComponentInstance ci, DialogPtr dialog, short itemOffset)
 FIVEWORDINLINE(0x2F3C, 0x0006, 0x0006, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelValidateInput(ComponentInstance ci, Boolean *ok)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0007, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelGetSettingsIdentifiers(ComponentInstance ci, short *theID, OSType *theType)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0008, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelGetSettings(ComponentInstance ci, Handle *userDataHand, long flags, DialogPtr theDialog, long itemsOffset)
 FIVEWORDINLINE(0x2F3C, 0x0010, 0x0009, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelSetSettings(ComponentInstance ci, Handle userDataHand, long flags, DialogPtr theDialog, long itemsOffset)
 FIVEWORDINLINE(0x2F3C, 0x0010, 0x000A, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelGetFidelity(ComponentInstance panelComponent, DisplayIDType displayID, DMFidelityType *panelFidelity)
 FIVEWORDINLINE(0x2F3C, 0x0008, 0x0100, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelComponentTargetDevice(ComponentInstance panelComponent, DisplayIDType displayID, DialogPtr theDialog, long itemsOffset)
 FIVEWORDINLINE(0x2F3C, 0x000C, 0x0101, 0x7000, 0xA82A);

extern pascal ComponentResult AVPanelComponentGetPanelClass(ComponentInstance panelComponent, ResType *panelClass, ResType *subClass, Ptr reserved1, Ptr reserved2)
 FIVEWORDINLINE(0x2F3C, 0x0010, 0x0102, 0x7000, 0xA82A);

/* =============================				*/
/* Port Component Standard Component selectors	*/
/* =============================				*/
extern pascal ComponentResult AVPortGetAVDeviceFidelity(ComponentInstance portComponent, AVIDType deviceAVID, DMFidelityType *portFidelity)
 FIVEWORDINLINE(0x2F3C, 0x0008, 0x0100, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortGetWiggle(ComponentInstance portComponent, Boolean *wiggleDevice)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0101, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortSetWiggle(ComponentInstance portComponent, Boolean wiggleDevice)
 FIVEWORDINLINE(0x2F3C, 0x0002, 0x0102, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortGetName(ComponentInstance portComponent, Str255 portName)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0103, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortGetGraphicInfo(ComponentInstance portComponent, PicHandle *thePict, Handle *theIconSuite, AVLocationPtr theLocation)
 FIVEWORDINLINE(0x2F3C, 0x000C, 0x0104, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortSetActive(ComponentInstance portComponent, Boolean setActive)
 FIVEWORDINLINE(0x2F3C, 0x0002, 0x0105, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortGetActive(ComponentInstance portComponent, Boolean *isPortActive, Boolean *portCanBeActivated, void *reserved)
 FIVEWORDINLINE(0x2F3C, 0x0008, 0x0106, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortGetAVID(ComponentInstance portComponent, AVIDType *avDeviceID)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0108, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortSetAVID(ComponentInstance portComponent, AVIDType avDeviceID)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0109, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortSetDeviceAVID(ComponentInstance portComponent, AVIDType avDeviceID)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x010A, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortGetDeviceAVID(ComponentInstance portComponent, AVIDType *avDeviceID)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x010B, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortGetPowerState(ComponentInstance deviceComponent, AVPowerStatePtr getPowerState)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x010C, 0x7000, 0xA82A);

extern pascal ComponentResult AVPortSetPowerState(ComponentInstance deviceComponent, AVPowerStatePtr setPowerState)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x010D, 0x7000, 0xA82A);

/* =============================				*/
/* Video Out Port Component Selectors			*/
/* =============================				*/
extern pascal ComponentResult AVPortCheckTimingMode(ComponentInstance displayComponent, DisplayIDType theDisplayID, VDDisplayConnectInfoPtr connectInfo, VDTimingInfoPtr modeTiming, unsigned long reserved)
 FIVEWORDINLINE(0x2F3C, 0x0010, 0x0000, 0x7000, 0xA82A);

/* =============================				*/
/* AV Device Component Selectors				*/
/* =============================				*/
extern pascal ComponentResult AVDeviceGetName(ComponentInstance portComponent, Str255 portName)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0100, 0x7000, 0xA82A);

extern pascal ComponentResult AVDeviceGetGraphicInfo(ComponentInstance portComponent, PicHandle *thePict, Handle *theIconSuite, AVLocationPtr theLocation)
 FIVEWORDINLINE(0x2F3C, 0x000C, 0x0101, 0x7000, 0xA82A);

extern pascal ComponentResult AVDeviceGetPowerState(ComponentInstance deviceComponent, AVPowerStatePtr getPowerState)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0102, 0x7000, 0xA82A);

extern pascal ComponentResult AVDeviceSetPowerState(ComponentInstance deviceComponent, AVPowerStatePtr setPowerState)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0103, 0x7000, 0xA82A);

extern pascal ComponentResult AVDeviceSetAVID(ComponentInstance deviceComponent, AVIDType avDeviceID)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0105, 0x7000, 0xA82A);

#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __AVCOMPONENTS__ */

